@@ -12,7 +12,7 @@ from theme_config import *
 
 project = "limits"
 description = "limits is a python library to perform rate limiting with commonly used storage backends"
-copyright = "2022, Ali-Akber Saifee"
+copyright = "2023, Ali-Akber Saifee"
 if ".post0.dev" in limits.__version__:
     version, ahead = limits.__version__.split(".post0.dev")
 else:
@@ -78,4 +78,6 @@ intersphinx_mapping = {
     "redis-py": ("https://redis-py.readthedocs.io/en/latest/", None),
     "pymemcache": ("https://pymemcache.readthedocs.io/en/latest/", None),
     "pymongo": ("https://pymongo.readthedocs.io/en/stable/", None),
+    "python-etcd3": ("https://python-etcd3.readthedocs.io/en/latest/", None),
+    "aetcd": ("https://aetcd.readthedocs.io/en/latest/", None),
 }
