@@ -3,6 +3,7 @@ import platform
 import socket
 import time
 
+import etcd3
 import pymemcache
 import pymemcache.client
 import pymongo
@@ -18,8 +19,17 @@ def check_redis_cluster_ready(host, port):
         return False
 
 
-def check_redis_ssl_cluster_ready(host, port):
+def check_redis_auth_cluster_ready(host, port):
+    try:
+        return (
+            redis.Redis(host, port, password="sekret").cluster("info")["cluster_state"]
+            == "ok"
+        )
+    except Exception:
+        return False
 
+
+def check_redis_ssl_cluster_ready(host, port):
     storage_url = (
         "rediss://localhost:8301/?ssl_cert_reqs=required"
         "&ssl_keyfile=./tests/tls/client.key"
@@ -65,6 +75,14 @@ def check_mongo_ready(host, port):
         return False
 
 
+def check_etcd_ready(host, port):
+    try:
+        etcd3.client(host, port).status()
+        return True
+    except:  # noqa
+        return False
+
+
 @pytest.fixture(scope="session")
 def host_ip_env():
     s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
@@ -83,6 +101,16 @@ def docker_services(host_ip_env, docker_services):
     return docker_services
 
 
+@pytest.fixture(scope="session")
+def etcd_client(docker_services):
+    docker_services.start("etcd")
+    docker_services.wait_for_service("etcd", 2379, check_etcd_ready)
+    if os.environ.get("CI") == "True":
+        time.sleep(5)
+
+    return etcd3.client()
+
+
 @pytest.fixture(scope="session")
 def redis_basic_client(docker_services):
     docker_services.start("redis-basic")
@@ -129,6 +157,18 @@ def redis_cluster_client(docker_services):
     return redis.cluster.RedisCluster("localhost", 7001)
 
 
+@pytest.fixture(scope="session")
+def redis_auth_cluster_client(docker_services):
+    docker_services.start("redis-cluster-auth-init")
+    docker_services.wait_for_service(
+        "redis-cluster-auth-3", 8402, check_redis_auth_cluster_ready
+    )
+    if os.environ.get("CI") == "True":
+        time.sleep(10)
+
+    return redis.cluster.RedisCluster("localhost", 8400, password="sekret")
+
+
 @pytest.fixture(scope="session")
 def redis_ssl_cluster_client(docker_services):
     docker_services.start("redis-ssl-cluster-init")
@@ -257,6 +297,13 @@ def redis_cluster(redis_cluster_client):
     return redis_cluster_client
 
 
+@pytest.fixture
+def redis_auth_cluster(redis_auth_cluster_client):
+    redis_auth_cluster_client.flushall()
+
+    return redis_auth_cluster_client
+
+
 @pytest.fixture
 def redis_ssl_cluster(redis_ssl_cluster_client):
     redis_ssl_cluster_client.flushall()
@@ -286,6 +333,12 @@ def mongodb(mongodb_client):
     return mongodb_client
 
 
+@pytest.fixture
+def etcd(etcd_client):
+    etcd_client.delete_prefix("limits/")
+    return etcd_client
+
+
 @pytest.fixture(scope="session")
 def docker_services_project_name():
     return "limits"
